@@ -1,11 +1,14 @@
+import warnings
 from django import VERSION
 from django.conf import settings
 from django.contrib.sites.models import Site
 from django.template import TemplateDoesNotExist
 
-from dbtemplates.models import Template, backend
+from dbtemplates.models import Template
+from dbtemplates.utils import cache, get_cache_key
 
-def load_template_source(template_name, template_dirs=None):
+
+def load_template_source(template_name, template_dirs=None, annoy=True):
     """
     A custom template loader to load templates from the database.
 
@@ -14,20 +17,18 @@ def load_template_source(template_name, template_dirs=None):
     it falls back to query the database field ``name`` with the template path
     and ``sites`` with the current site.
     """
-    if VERSION[:2] >= (1, 2):
+    if VERSION[:2] >= (1, 2) and annoy:
         # For backward compatibility
-        import warnings
         warnings.warn(
             "`dbtemplates.loader.load_template_source` is deprecated; "
-            "use `dbtemplates.loader.Loader` instead.",
-            PendingDeprecationWarning
-        )
+            "use `dbtemplates.loader.Loader` instead.", DeprecationWarning)
     site = Site.objects.get_current()
     display_name = 'db:%s:%s:%s' % (settings.DATABASE_ENGINE,
                                     template_name, site.domain)
-    if backend:
+    cache_key = get_cache_key(template_name)
+    if cache:
         try:
-            backend_template = backend.load(template_name)
+            backend_template = cache.get(cache_key)
             if backend_template:
                 return backend_template, template_name
         except:
@@ -35,8 +36,8 @@ def load_template_source(template_name, template_dirs=None):
     try:
         template = Template.on_site.get(name__exact=template_name)
         # Save in cache backend explicitly if manually deleted or invalidated
-        if backend:
-            backend.save(template_name, template.content)
+        if cache:
+            cache.set(cache_key, template.content)
         return (template.content, display_name)
     except:
         pass
@@ -54,5 +55,5 @@ if VERSION[:2] >= (1, 2):
         is_usable = True
 
         def load_template_source(self, template_name, template_dirs=None):
-            return load_template_source(template_name, template_dirs)
-
+            return load_template_source(
+                template_name, template_dirs, annoy=False)
